==> haskell-concurrent-output-1.10.10-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.10.10
id: concurrent-output-1.10.10-4Z5EUzvziEiJ4FL8oiDqzN
key: concurrent-output-1.10.10-4Z5EUzvziEiJ4FL8oiDqzN
license: BSD-2-Clause
copyright: 2015-2017 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
author: Joey Hess, Joachim Breitner
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
abi: 79b2ad29948f1b73d068124248733287
exposed: True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
import-dirs: /usr/lib/ghc-8.6.5/site-local/concurrent-output-1.10.10
library-dirs: /usr/lib/ghc-8.6.5/site-local/concurrent-output-1.10.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/concurrent-output-1.10.10
hs-libraries: HSconcurrent-output-1.10.10-4Z5EUzvziEiJ4FL8oiDqzN
depends:
    ansi-terminal-0.9.1-DB3Zf3I0Zem5oqZIKoyRWZ
    async-2.2.1-GYH0rb5jjEHH7NChV9fWYh base-4.12.0.0 directory-1.3.3.0
    exceptions-0.10.2-D9MYzhqXvqCL8hMQL1PEiN process-1.6.5.0
    stm-2.5.0.0 terminal-size-0.3.2.1-Hh6hFaOyLfiJ6x0AenX2yY
    text-1.2.3.1 transformers-0.5.6.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-concurrent-output-1.10.10-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-concurrent-output.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: concurrent-output
version: 1.10.10
id: concurrent-output-1.10.10-2RkKPufi53xHGYqpVE1wx5
key: concurrent-output-1.10.10-2RkKPufi53xHGYqpVE1wx5
license: BSD-2-Clause
copyright: 2015-2017 Joey Hess, 2009 Joachim Breitner
maintainer: Joey Hess <id@joeyh.name>
author: Joey Hess, Joachim Breitner
stability: Stable
synopsis: Ungarble output from several threads or commands
description:
    Lets multiple threads and external processes concurrently output to the
    console, without it getting all garbled up.
    .
    Built on top of that is a way of defining multiple output regions,
    which are automatically laid out on the screen and can be individually
    updated by concurrent threads. Can be used for progress displays etc.
    .
    <<https://joeyh.name/code/concurrent-output/demo2.gif>>
category: User Interfaces
abi: 9229aea5574dfd4c4c44afee6d6eb156
exposed: True
exposed-modules:
    System.Console.Concurrent System.Console.Concurrent.Internal
    System.Console.Regions System.Process.Concurrent
hidden-modules: Utility.Monad Utility.Data Utility.Exception
import-dirs: /usr/lib/ghc-8.6.5/site-local/concurrent-output-1.10.10
library-dirs: /usr/lib/ghc-8.6.5/site-local/concurrent-output-1.10.10
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/concurrent-output-1.10.10
hs-libraries: HSconcurrent-output-1.10.10-2RkKPufi53xHGYqpVE1wx5
depends:
    ansi-terminal-0.9.1-JvtMBmSUh1eHKvsAMwthXj
    async-2.2.2-5KbUJa8fnnu9oaTmXcEjsG base-4.12.0.0 directory-1.3.3.0
    exceptions-0.10.2-EJs0RkZsum56ksbfDqbl1F process-1.6.5.0
    stm-2.5.0.0 terminal-size-0.3.2.1-Hh6hFaOyLfiJ6x0AenX2yY
    text-1.2.3.1 transformers-0.5.6.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-concurrent-output/html/concurrent-output.haddock
haddock-html: /usr/share/doc/haskell-concurrent-output/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
